Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/blenlib/BLI_delaunay_2d.h')
-rw-r--r--source/blender/blenlib/BLI_delaunay_2d.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/blenlib/BLI_delaunay_2d.h b/source/blender/blenlib/BLI_delaunay_2d.h
index 9c4c2b4d978..9fb049ff2b9 100644
--- a/source/blender/blenlib/BLI_delaunay_2d.h
+++ b/source/blender/blenlib/BLI_delaunay_2d.h
@@ -162,10 +162,10 @@ typedef enum CDT_output_type {
* API interface to CDT.
* This returns a pointer to an allocated CDT_result.
* When the caller is finished with it, the caller
* should use #BLI_constrained_delaunay_free() to free it.
*/
-CDT_result *BLI_constrained_delaunay(const CDT_input *input, const CDT_output_type output_type);
+CDT_result *BLI_delaunay_2d_cdt_calc(const CDT_input *input, const CDT_output_type output_type);
-void BLI_constrained_delaunay_free(CDT_result *result);
+void BLI_delaunay_2d_cdt_free(CDT_result *result);
#endif /* __BLI_DELAUNAY_2D_H__ */
@@ -162,10 +162,10 @@ typedef enum CDT_output_type {
* This returns a pointer to an allocated CDT_result.
* When the caller is finished with it, the caller
- * should use #BLI_constrained_delaunay_free() to free it.
+ * should use #BLI_delaunay_2d_cdt_free() to free it.
*/